# Taskrabbit

[![Documentation Status](https://readthedocs.org/projects/taskrabbit/badge/?version=latest&style=flat)](http://taskrabbit.readthedocs.org)

Command line utility for moving Celery task messages
in and out of RabbitMQ.

Features multiple storage backends, currently SQLite, PostgreSQL, and file-based
task stores are implemented.

## Installation

Taskrabbit is developed and tested on Python 3.8

`python3 -m pip install --user taskrabbit`

## Documentation

View the [Taskrabbit documentation](https://taskrabbit.readthedocs.io/en/latest/) online at ReadTheDocs.

## Demo

[![TaskRabbit Demo Video](https://i.vimeocdn.com/video/1015490294.jpg?mw=960&mh=540)](https://vimeo.com/490947780)
